@@ -5,7 +5,7 @@ from state_manager.filters.logic import text_in_list, text_contains, text_matche
 
 
 class TextFilter(BaseTextFilter):
-    def check(self, msg: types.Message) -> bool:
+    def check(self, msg: types.Message) -> bool:  # type: ignore
         text = msg.text
         if text is None:
             return False
@@ -16,7 +16,7 @@ class TextFilter(BaseTextFilter):
 
 
 class TextContainsFilter(BaseTextContainsFilter):
-    def check(self, msg: types.Message) -> bool:
+    def check(self, msg: types.Message) -> bool:  # type: ignore
         text = msg.text
         if text is None:
             return False
@@ -27,7 +27,7 @@ class TextContainsFilter(BaseTextContainsFilter):
 
 
 class RegexFilter(BaseRegexFilter):
-    def check(self, msg: types.Message) -> bool:
+    def check(self, msg: types.Message) -> bool:  # type: ignore
         text = msg.text
         if text is None:
             return False
