@@ -6,7 +6,7 @@ from state_manager.filters.logic import text_in_list, text_contains, text_matche
 
 
 class TextFilter(BaseTextFilter):
-    def check(self, event: BaseEvent) -> bool:
+    def check(self, event: BaseEvent) -> bool:  # type: ignore
         text = get_text(event)
         if text is None:
             return False
@@ -17,7 +17,7 @@ class TextFilter(BaseTextFilter):
 
 
 class TextContainsFilter(BaseTextContainsFilter):
-    def check(self, event: BaseEvent) -> bool:
+    def check(self, event: BaseEvent) -> bool:  # type: ignore
         text = get_text(event)
         if text is None:
             return False
@@ -28,7 +28,7 @@ class TextContainsFilter(BaseTextContainsFilter):
 
 
 class RegexFilter(BaseRegexFilter):
-    def check(self, event: BaseEvent) -> bool:
+    def check(self, event: BaseEvent) -> bool:  # type: ignore
         text = get_text(event)
         if text is None:
             return False
